/*
 * This code is taken from the official Window List Gnome Shell extension.
 *
 * Licensing information:
 * Window List Gnome Shell extension is distributed under the terms
 * of the GNU General Public License, version 2 or later.
 */

const Lang = imports.lang;
const Main = imports.ui.main;
const Clutter = imports.gi.Clutter;
const Gio = imports.gi.Gio;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();
const WindowList = Me.imports.windowList;

const ZORIN_PANEL_UUID = "zorin-panel@zorinos.com";

let monitorsChangedId

function _init() {
}

function enable() {
    monitorsChangedId =
        Main.layoutManager.connect('monitors-changed', _buildWindowList);

    this._buildWindowList();
}

function _buildWindowList() {
    if (Main.windowList)
        Main.windowList.actor.destroy();

    Main.windowList = new WindowList.WindowList(Main.layoutManager.primaryMonitor);

    // Allows the Zorin Panel extension to work with the Window List
    if (ExtensionUtils.extensions[ZORIN_PANEL_UUID]) {
        ExtensionUtils.extensions[ZORIN_PANEL_UUID].imports.extension.intellihide.enableWindowList();
        ExtensionUtils.extensions[ZORIN_PANEL_UUID].imports.extension.dynamicTransparency.enableWindowList();
        ExtensionUtils.extensions[ZORIN_PANEL_UUID].imports.extension.positionHeight.enableWindowList();
    }
}

function disable() {
    if (ExtensionUtils.extensions[ZORIN_PANEL_UUID]) {
        ExtensionUtils.extensions[ZORIN_PANEL_UUID].imports.extension.intellihide.disableWindowList();
        ExtensionUtils.extensions[ZORIN_PANEL_UUID].imports.extension.dynamicTransparency.disableWindowList();
        ExtensionUtils.extensions[ZORIN_PANEL_UUID].imports.extension.positionHeight.disableWindowList();
    }

    Main.layoutManager.disconnect(monitorsChangedId);
    monitorsChangedId = 0;

    Main.windowList.actor.hide();
    Main.windowList.actor.destroy();

    Main.windowList = null;
}

function someWindowListContains(actor) {
    return Main.windowList.actor.contains(actor);
}
